# Connector

A connector describes the relative motions between two points. A connector also describes the behavior associated with the relative motion.

## Create connectors

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorSection.ConnectorSection
    :members:
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Connector
        :recursive:
        :exclude: ConnectorSection

    .. placeholder for empty members
```
